@@ -1,5 +1,7 @@
 package Schedule::LongSteps::Storage::AutoDBIx::Schema;
-$Schedule::LongSteps::Storage::AutoDBIx::Schema::VERSION = '0.014';
+$Schedule::LongSteps::Storage::AutoDBIx::Schema::VERSION = '0.015';
+use strict;
+use warnings;
 use base qw/DBIx::Class::Schema/;
 
 __PACKAGE__->load_classes({ 'Schedule::LongSteps::Storage::AutoDBIx::Schema::Result' => [ 'LongstepProcess' ] });
